#
# spec file for package pdfmixtool
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pdfmixtool
Version:        1.1.1
Release:        3.5
Summary:        Split, Merge, Rotate and Mix PDF Files
License:        GPL-3.0-only
Group:          Productivity/Publishing/PDF
URL:            https://gitlab.com/scarpetta/pdfmixtool/
Source0:        https://gitlab.com/scarpetta/pdfmixtool/-/archive/v%{version}/%{name}-v%{version}.tar.bz2
Patch1:         stop_using_obsolete_standards.patch
# PATCH-FIX-OPENSUSE fix-missing-definitions.patch munix9@googlemail.com -- Add missing definitions for Factory/TW
Patch2:         fix-missing-definitions.patch
BuildRequires:  cmake
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(Magick++)
BuildRequires:  pkgconfig(libqpdf)

%description
An application to split, merge, rotate, mix and create multipage PDF files.

%prep
%autosetup -p1 -n %{name}-v%{version}

%build
%cmake
%cmake_build

%install
%cmake_install
%suse_update_desktop_file -r -G "PDF Tools" eu.scarpetta.PDFMixTool Qt Office Publishing Graphics Viewer

%files
%license LICENSE
%doc AUTHORS.md CHANGELOG.md README.md TRANSLATORS.md
%{_bindir}/pdfmixtool
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/metainfo/*.xml

%changelog
* Sat Oct  7 2023 munix9@googlemail.com
- Add patch fix-missing-definitions.patch: Add missing definitions
  MAGICKCORE_HDRI_ENABLE/MAGICKCORE_QUANTUM_DEPTH for Factory/TW.
* Wed Mar  1 2023 Adam Majer <adam.majer@suse.de>
- stop_using_obsolete_standards.patch: stop clamping to obsolete
  standards like C++11 while build depenedencies now require C++17
  or later. Use compiler defaults instead.
* Tue Oct 11 2022 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 1.1.1:
  * Fix incompatibility with qpdf 11
  * Allow GraphicsMagick as an alternative to ImageMagick
* Tue Jun 28 2022 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 1.1:
  * Add "Extract images" operation
  * Improve GUI appearance and HiDPI support
  * Add options to generate two booklets in one sheet
- Added new build requirements: cmake(Qt5Svg), cmake(Qt5Xml) and
  pkgconfig(Magick++).
* Thu Jun 24 2021 Asterios Dramis <asterios.dramis@gmail.com>
- Removed fix for rpmlint warning "files-duplicate" and fdupes
  build requirement (not needed anymore).
* Thu Jun 24 2021 ecsos <ecsos@opensuse.org>
- Update to 1.0.2
  - Improve compatibility with stable distros and multiarch distros
- Drop qpdf9.patch because now in upstream.
* Wed Jun 16 2021 Asterios Dramis <asterios.dramis@gmail.com>
- Apply qpdf9.patch only for Leap <= 15.2. Leap 15.3 has qpdf10.
* Tue Jun 15 2021 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 1.0.1:
  * Interface has been overhauled to make it more intuitive
  * Links, annotations, outlines are now preserved as much as
    possible in all operations
  * Add Qt 6 support
  * Add right-to-left support in pages composition
  * Add ability to edit PDF document information
- Fix rpmlint warning "files-duplicate". Added fdupes build
  requirement for this.
- Rebased qpdf9.patch to apply cleanly.
* Thu May 27 2021 Asterios Dramis <asterios.dramis@gmail.com>
- Use %%cmake_build.
* Fri Jul 17 2020 Asterios Dramis <asterios.dramis@gmail.com>
- Fix desktop file rpm post build check error in Leap.
* Fri Jul 17 2020 Asterios Dramis <asterios.dramis@gmail.com>
- Added a patch "qpdf9.patch" to fix compilation with qpdf-9 in
  Leap.
* Sun May 24 2020 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 0.6:
  * Add ability to save and restore the list of input PDF files
  * Add Swedish translation
  * Remove dependency on PoDoFo
  * Various fixes and UI improvements
- Removed libpodofo-devel build requirement (not needed anymore).
- Use cmake(Qt5...) for all Qt5 build requirements.
* Thu Apr 30 2020 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 0.5:
  * New "Single file" mode with the following operations:
  - Booklet
  - Edit page layout
  - Add empty pages
  - Delete pages
  - Extract pages
  * Add alternate mix merge feature
  * Better multipage profiles management
  * Add Croatian translation
  * Add Czech translation
  * Add Polish translation
* Sat Feb  8 2020 Asterios Dramis <asterios.dramis@gmail.com>
- Initial rpm release (version 0.4).
